@@ -11,7 +11,7 @@ use Moo;
 use IPC::Run3; # For run3().
 use Types::Standard qw/Any ArrayRef HasMethods HashRef Int Str/;
 
-our $VERSION = '2.56';
+our $VERSION = '2.57';
 
 my $DATA_SECTION = get_data_section; # load once
 
@@ -190,7 +190,6 @@ sub BUILD
 		name			=> $$globals{name} // 'Perl',
 		record_shape	=> ($$globals{record_shape} && $$globals{record_shape} =~ /^(M?record)$/) ? $1 : 'Mrecord',
 		strict			=> $$globals{strict} //  0,
-		subgraph		=> $$globals{subgraph} || {},
 		timeout			=> $$globals{timeout} // 10,
 	};
 	my($im_metas)	= $self -> im_meta;
@@ -387,7 +386,7 @@ sub default_edge
 	$self->validate_params('edge', \%arg);
 
 	my $scope    = $self->scope->[-1];
-	$$scope{edge} = {%{$$scope{edge} }, %arg};
+	$$scope{edge} = {%{$$scope{edge} || {}}, %arg};
 
 	push @{ $self->command }, _indent($self->stringify_attributes('edge', $$scope{edge}), $self->scope);
 	$self -> log(debug => 'Default edge: ' . join(', ', map{"$_ => $$scope{edge}{$_}"} sort keys %{$$scope{edge} }) );
@@ -405,7 +404,7 @@ sub default_graph
 	$self->validate_params('graph', \%arg);
 
 	my $scope    = $self->scope->[-1];
-	$$scope{graph} = {%{$$scope{graph} }, %arg};
+	$$scope{graph} = {%{$$scope{graph} || {}}, %arg};
 
 	push @{ $self->command }, _indent($self->stringify_attributes('graph', $$scope{graph}), $self->scope);
 	$self -> log(debug => 'Default graph: ' . join(', ', map{"$_ => $$scope{graph}{$_}"} sort keys %{$$scope{graph} }) );
@@ -423,7 +422,7 @@ sub default_node
 	$self->validate_params('node', \%arg);
 
 	my $scope    = $self->scope->[-1];
-	$$scope{node} = {%{$$scope{node} }, %arg};
+	$$scope{node} = {%{$$scope{node} || {}}, %arg};
 
 	push @{ $self->command }, _indent($self->stringify_attributes('node', $$scope{node}), $self->scope);
 	$self -> log(debug => 'Default node: ' . join(', ', map{"$_ => $$scope{node}{$_}"} sort keys %{$$scope{node} }) );
@@ -441,7 +440,7 @@ sub default_subgraph
 	$self->validate_params('subgraph', \%arg);
 
 	my $scope    = $self->scope->[-1];
-	$$scope{subgraph} = {%{$$scope{subgraph} }, %arg};
+	$$scope{subgraph} = {%{$$scope{subgraph} || {}}, %arg};
 
 	push @{ $self->command }, _indent($self->stringify_attributes('subgraph', $$scope{subgraph}), $self->scope);
 	$self -> log(debug => 'Default subgraph: ' . join(', ', map{"$_ => $$scope{subgraph}{$_}"} sort keys %{$$scope{subgraph} }) );
@@ -530,16 +529,10 @@ sub push_subgraph
 	$self->validate_params('edge',     $arg{edge});
 	$self->validate_params('subgraph', $arg{subgraph});
 
-	# Child inherits parent attributes.
-
-	my $scope        = $self->scope->[-1];
-	$$scope{edge}     = {%{$$scope{edge} || {}}, %{$arg{edge} || {}}};
-	$$scope{graph}    = {%{$$scope{graph} || {}}, %{$arg{graph} || {}}};
-	$$scope{node}     = {%{$$scope{node} || {}}, %{$arg{node} || {}}};
-	$$scope{subgraph} = {%{$$scope{subgraph} || {}}, %{$arg{subgraph} || {}}};
+	$arg{subgraph} = { %{ $self->subgraph||{} }, %{$arg{subgraph}||{}} };
 
 	push @{ $self->command }, "\n" . _indent(join(' ', grep length, "subgraph", $name, "{\n"), $self->scope);
-	push @{ $self->scope }, $scope;
+	push @{ $self->scope }, \%arg;
 	$self -> default_graph;
 	$self -> default_node;
 	$self -> default_edge;
@@ -742,14 +735,6 @@ See L<https://graphviz-perl.github.io/>.
 	my $output_file = shift || File::Spec->catfile('html', "sub.graph.$format");
 	$graph->run(format => $format, output_file => $output_file);
 
-This program ships as scripts/sub.graph.pl. See L</Scripts Shipped with this Module>.
-
-=head3 Image Maps Usage
-
-As of V 2.43, C<GraphViz2> supports image maps, both client and server side.
-
-See L</Image Maps> below.
-
 =head1 Description
 
 =head2 Overview
@@ -890,34 +875,6 @@ The default is 0.
 
 This key is optional.
 
-=item o subgraph => $hashref
-
-The I<subgraph> key points to a hashref which is used to set attributes for all subgraphs, unless overridden
-for specific subgraphs in a call of the form push_subgraph(subgraph => {$attribute => $string}).
-
-Valid keys within this hashref are:
-
-=over 4
-
-=item o rank => $string
-
-This option affects the content of all subgraphs, unless overridden later.
-
-A typical usage would be new(subgraph => {rank => 'same'}) so that all nodes mentioned within each subgraph
-are constrained to be horizontally aligned.
-
-See scripts/rank.sub.graph.[12].pl for sample code.
-
-Possible values for $string are: max, min, same, sink and source.
-
-See the L<Graphviz 'rank' docs|http://www.graphviz.org/doc/info/attrs.html#d:rank> for details.
-
-=back
-
-The default is {}.
-
-This key is optional.
-
 =item o timeout => $integer
 
 This option specifies how long to wait for the external program before exiting with an error.
@@ -970,6 +927,34 @@ The default is {}.
 
 This key is optional.
 
+=item o subgraph => $hashref
+
+The I<subgraph> key points to a hashref which is used to set attributes for all subgraphs, unless overridden
+for specific subgraphs in a call of the form push_subgraph(subgraph => {$attribute => $string}).
+
+Valid keys within this hashref are:
+
+=over 4
+
+=item o rank => $string
+
+This option affects the content of all subgraphs, unless overridden later.
+
+A typical usage would be new(subgraph => {rank => 'same'}) so that all nodes mentioned within each subgraph
+are constrained to be horizontally aligned.
+
+See scripts/rank.sub.graph.1.pl for sample code.
+
+Possible values for $string are: max, min, same, sink and source.
+
+See the L<Graphviz 'rank' docs|http://www.graphviz.org/doc/info/attrs.html#d:rank> for details.
+
+=back
+
+The default is {}.
+
+This key is optional.
+
 =item o verbose => $Boolean
 
 Provides a way to control the amount of output when a logger is not specified.
@@ -1081,6 +1066,8 @@ this issue, including a special color of 'invisible'.
 =head1 Image Maps
 
 As of V 2.43, C<GraphViz2> supports image maps, both client and server side.
+For web use, note that these options also take effect when generating SVGs,
+for a much lighter-weight solution to hyperlinking graph nodes and edges.
 
 =head2 The Default URL
 
@@ -2000,7 +1987,6 @@ label
 name
 record_shape
 strict
-subgraph
 timeout
 
 @@ im_meta
